@@ -1,9 +1,9 @@
 package App::dateseq;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-01-13'; # DATE
+our $DATE = '2021-08-22'; # DATE
 our $DIST = 'App-dateseq'; # DIST
-our $VERSION = '0.102'; # VERSION
+our $VERSION = '0.103'; # VERSION
 
 use 5.010001;
 use strict;
@@ -259,7 +259,7 @@ _
 See also <prog:dateseq-id> as alternative.
 
 _
-            src => 'setop --diff <([[prog]] 2015-01-01 2015-12-31) <(list-id-holidays --year 2015)',
+            src => 'setop --diff <([[prog]] 2015-01-01 2015-12-31) <(list-idn-holidays --year 2015)',
             src_plang => 'bash',
             'x.doc.max_result_lines' => 10,
         },
@@ -270,7 +270,7 @@ _
 See also <prog:dateseq-id> as alternative.
 
 _
-            src => 'setop --diff <([[prog]] 2015-01-01 2015-12-31 --business) <(list-id-holidays --year 2015)',
+            src => 'setop --diff <([[prog]] 2015-01-01 2015-12-31 --business) <(list-idn-holidays --year 2015)',
             src_plang => 'bash',
             'x.doc.max_result_lines' => 10,
         },
@@ -443,7 +443,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.102 of App::dateseq (from Perl distribution App-dateseq), released on 2021-01-13.
+This document describes version 0.103 of App::dateseq (from Perl distribution App-dateseq), released on 2021-08-22.
 
 =head1 FUNCTIONS
 
@@ -452,7 +452,7 @@ This document describes version 0.102 of App::dateseq (from Perl distribution Ap
 
 Usage:
 
- dateseq(%args) -> [status, msg, payload, meta]
+ dateseq(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Generate a sequence of dates.
 
@@ -557,12 +557,12 @@ End date, if not specified will generate an infinite* stream of dates.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -576,7 +576,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-dateseq>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-dateseq/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-dateseq>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -588,7 +588,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
